==> fwbuilder_2.0.7.orig.tar.gz: fwbuilder-2.0.7/src/gui/PrintingProgressDialog.h <==
/* 

                          Firewall Builder

                 Copyright (C) 2003 NetCitadel, LLC

  Author:  Vadim Kurland     vadim@fwbuilder.org

  $Id: PrintingProgressDialog.h,v 1.2 2005/01/23 05:32:06 vkurland Exp $

  This program is free software which we release under the GNU General Public
  License. You may redistribute and/or modify this program under the terms
  of that license as published by the Free Software Foundation; either
  version 2 of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
 
  To get a copy of the GNU General Public License, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*/


#ifndef  __PRINTINGPROGRESSDIALOG_H_
#define  __PRINTINGPROGRESSDIALOG_H_

#include "printingprogressdialog_q.h"

#include <qwidget.h>
#include <qprinter.h>

#include <vector>

class PrintingProgressDialog : public printingProgressDialog_q {

    QPrinter *printer;
    int       totalPages;
    
 public:

    PrintingProgressDialog(QWidget *parent,QPrinter *p,int nPages,bool disableCancel);

    void setCurrentPageNo(int n);
    void genericProgressIndicator(int n,const QString &txt);
    void setNPages(int n);

 public slots:

     virtual void abortPrinting();
};


#endif

==> fwbuilder_3.0.7.orig.tar.gz: fwbuilder-3.0.7/src/gui/PrintingProgressDialog.h <==
/* 

                          Firewall Builder

                 Copyright (C) 2003 NetCitadel, LLC

  Author:  Vadim Kurland     vadim@fwbuilder.org

  $Id: PrintingProgressDialog.h 304 2008-07-03 02:19:16Z vadim $

  This program is free software which we release under the GNU General Public
  License. You may redistribute and/or modify this program under the terms
  of that license as published by the Free Software Foundation; either
  version 2 of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
 
  To get a copy of the GNU General Public License, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*/


#ifndef  __PRINTINGPROGRESSDIALOG_H_
#define  __PRINTINGPROGRESSDIALOG_H_

#include <ui_printingprogressdialog_q.h>

#include <qwidget.h>
#include <qdialog.h>
#include <qprinter.h>

#include <vector>

class PrintingProgressDialog : public QDialog {

    Q_OBJECT

    QPrinter *printer;
    int       totalPages;
    Ui::printingProgressDialog_q *m_dialog;
    
 public:

    PrintingProgressDialog(QWidget *parent,QPrinter *p,int nPages,bool disableCancel);
    ~PrintingProgressDialog();

    void setCurrentPageNo(int n);
    void genericProgressIndicator(int n,const QString &txt);
    void setNPages(int n);

 public slots:

    void abortPrinting();

};


#endif
